Struct BoundingBox
pub struct BoundingBox {
pub x0: f64,
pub y0: f64,
pub x1: f64,
pub y1: f64,
}Expand description
A bounding box.
Fields
x0: f64The left edge.
y0: f64The top edge.
x1: f64The right edge.
y1: f64The bottom edge.
Implementations
impl BoundingBox
impl BoundingBox
pub const fn new(x0: f64, y0: f64, x1: f64, y1: f64) -> BoundingBox
pub const fn new(x0: f64, y0: f64, x1: f64, y1: f64) -> BoundingBox
A new bounding box from minimum and maximum coordinates.
pub fn union(&self, other: BoundingBox) -> BoundingBox
pub fn union(&self, other: BoundingBox) -> BoundingBox
The smallest bounding box enclosing two bounding boxes.
Results are valid only if width and height are non-negative.